API Reference
=============

This section contains the complete API reference for Circuit Synth.

Core Module
-----------

.. automodule:: circuit_synth.core
   :members:
   :undoc-members:
   :show-inheritance:

Circuit
~~~~~~~

.. automodule:: circuit_synth.core.circuit
   :members:
   :undoc-members:
   :show-inheritance:

Component
~~~~~~~~~

.. automodule:: circuit_synth.core.component
   :members:
   :undoc-members:
   :show-inheritance:

Net
~~~

.. automodule:: circuit_synth.core.net
   :members:
   :undoc-members:
   :show-inheritance:

Pin
~~~

.. automodule:: circuit_synth.core.pin
   :members:
   :undoc-members:
   :show-inheritance:

KiCad Integration
-----------------

.. automodule:: circuit_synth.kicad
   :members:
   :undoc-members:
   :show-inheritance:

Unified Integration
~~~~~~~~~~~~~~~~~~~

.. automodule:: circuit_synth.kicad.unified_kicad_integration
   :members:
   :undoc-members:
   :show-inheritance:

PCB Generation
--------------

.. automodule:: circuit_synth.pcb
   :members:
   :undoc-members:
   :show-inheritance:

Placement Algorithms
~~~~~~~~~~~~~~~~~~~~

.. automodule:: circuit_synth.pcb.placement
   :members:
   :undoc-members:
   :show-inheritance:

Schematic Generation
--------------------

.. automodule:: circuit_synth.schematic
   :members:
   :undoc-members:
   :show-inheritance:

Component Placement
-------------------

.. automodule:: circuit_synth.component_placement
   :members:
   :undoc-members:
   :show-inheritance:

Interfaces
----------

.. automodule:: circuit_synth.interfaces
   :members:
   :undoc-members:
   :show-inheritance:

Exceptions
----------

.. automodule:: circuit_synth.core.exception
   :members:
   :undoc-members:
   :show-inheritance: